// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
/*

    Copyright (C) 2012-2017  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

function _getDash() {
    try { return Main.overview._dash; } catch(e) { return null; }
}

const GNOME_DASH = _getDash();

const KEY_SHOW_DASH = 'show-dash';

const Dash = new Lang.Class({
    Name: 'Dash',

    _init: function() {
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_DASH, Lang.bind(this, this._onShowDash));
        this._onShowDash();
    },

    _onShowDash: function() {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_DASH));
    },

    _updateVisibility: function(visible) {
        GNOME_DASH.actor.visible = visible;
        if (GNOME_DASH._container) GNOME_DASH._container.visible = visible;
    },

    destroy: function() {
        this._settings.disconnect(this._connectSettings);
        this._updateVisibility(true);
    }
});

function getExtension() {
    return GNOME_DASH ? new Dash() : null;
}
