// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
/*

    Copyright (C) 2012-2017  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const Shell = imports.gi.Shell;

const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;
const PanelTools = Me.imports.panelTools;

const Gettext = imports.gettext;
const _ = Gettext.domain(Convenience.CURRENT_GETTEXT_DOMAIN).gettext;

const KEY_SHOW_SHOWDESKTOP = 'show-showdesktop';

const ShowDesktopButton = new Lang.Class({
    Name: 'ShowDesktopButton',
    Extends: PanelTools.Button,

    _init: function() {
        this.parent(1.0, _("ShowDesktop"), { icon_name: 'video-display-symbolic', dontCreateMenu: true });
        this._windows = [];
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_SHOWDESKTOP, Lang.bind(this, this._onShowShowDesktop));
        this._onShowShowDesktop();
        this.actor.connect('button-press-event', Lang.bind(this, this._onButtonPressEvent));
        this.actor.connect('destroy', Lang.bind(this, function() {
            this._settings.disconnect(this._connectSettings);
        }));
    },

    _onButtonPressEvent: function() {
        let workspace = global.screen.get_active_workspace();
        let index = workspace.index();
        let windows = workspace.list_windows();
        let tracker = Shell.WindowTracker.get_default();
        if (this._windows[index]) {
            for (let i = 0; i < windows.length; i++) {
                if (tracker.get_window_app(windows[i])) {
                    let restore = true;
                    for (let j = 0; j < this._windows[index].length; j++) {
                        if (windows[i] == this._windows[index][j]) {
                            restore = false;
                            break;
                        }
                    }
                    if (restore) windows[i].unminimize();
                }
            }
            this._windows[index] = null;
        } else {
            this._windows[index] = [];
            for (let i = 0; i < windows.length; i++) {
                if (tracker.get_window_app(windows[i])) {
                    let canClose = windows[i].can_close ? windows[i].can_close() : true;
                    if (canClose && !windows[i].minimized) {
                        windows[i].minimize();
                    } else {
                        this._windows[index].push(windows[i]);
                    }
                }
            }
        }
        this.menu.close(0);
        Main.overview.hide();
    },

    _onShowShowDesktop: function() {
        this.updateVisibility(this._settings.get_boolean(KEY_SHOW_SHOWDESKTOP));
        PanelTools.updatePanelCorner(this, 'left');
    }
});

function getExtension() {
    return PanelTools.addToStatusArea('dschaerfShowDesktop', new ShowDesktopButton(), 1, 'left');
}
